LRB Search Results

| Slip Decisions Search Results
Search Criteria
Decision Start Date : 01/01/2005
Decision End Date : 02/01/2005
Court : Appellate Term, 1st Dept
Total number of records found: 19
Party Name | Decision Date | Court | Official Citation | Slip Number | Judge | Opn/Mot
3201-13 Park Realty LLC v Hernandez | 01/07/2005 | Appellate Term, 1st Dept | 6 Misc 3d 127(A) | 2005 NYSlipOp 50004(U) |  | Opinion
500 Lincoln LLC v Tunnel Self-Stor., LLC | 01/14/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50019(U) |  | Opinion
Bickham v Ventura | 01/06/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50001(U) |  | Opinion
Condor Funding, LLC v Myers | 01/12/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50014(U) |  | Opinion
Equity League Pension Fund v Cavallo | 01/14/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50020(U) |  | Opinion
Gazivoda v Sherman | 01/06/2005 | Appellate Term, 1st Dept | 6 Misc 3d 66 | 2005 NYSlipOp 25000 |  | Opinion
Gt Sys. Inc. v Jill Stuart Intl. Ltd. | 01/14/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50021(U) |  | Opinion
Lau v Berman | 01/12/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50015(U) |  | Opinion
Melnitzky v City of New York | 01/06/2005 | Appellate Term, 1st Dept | 6 Misc 3d 78 | 2005 NYSlipOp 25001 |  | Opinion
Moore v Fed Ex | 01/07/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50006(U) |  | Opinion
People v Alston (James) | 01/06/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50000(U) |  | Opinion
People v Delarosa (Juan) | 01/06/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50002(U) |  | Opinion
People v Hossack (Omar) | 01/07/2005 | Appellate Term, 1st Dept | 6 Misc 3d 127(A) | 2005 NYSlipOp 50005(U) |  | Opinion
Perez v Levine | 01/26/2005 | Appellate Term, 1st Dept |  | 2005 NYSlipOp Slip |  | Opinion
Perez v Levine | 01/26/2005 | Appellate Term, 1st Dept | 7 Misc 3d 29 | 2005 NYSlipOp 25023 |  | Opinion
RGHF&R Enters., Inc. v Stevens | 01/07/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50007(U) |  | Opinion
Rivera v Richardson | 01/12/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50016(U) |  | Opinion
Royal Terrace Assoc., LP v Jewish Assoc. for Servs. for the Aged | 01/26/2005 | Appellate Term, 1st Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50067(U) |  | Opinion
Tucker v Harvin | 01/12/2005 | Appellate Term, 1st Dept | 6 Misc 3d 128(A) | 2005 NYSlipOp 50017(U) |  | Opinion